# HIRO SDK CLI

CLI utils for HIRO applications.

## Project setup

#### Prerequisites

- node 16+
- yarn 1.22+

#### Instalation

- Run `yarn global add @hiro-ui/sdk-cli`

## Commands
 
### hiro-sdk bundle

Bundles compiled application into a zip archive.

We need to build our app first.
Run `yarn build` to create a production build.

As result, we expect a `build` folder in project root.
It should have the following structure:

```
build
├── asset-manifest.json
├── icon.svg
├── index.html
└── static
    ├── css
    │   └── main.2c2ee846.css
    └── js
        └── main.fb659025.js
```

**Important files**

`icon.svg` is used by HIRO Desktop as the icon of the application.

`asset-manifest.json` contains paths mapping for your assets.
`main.js` is **required**. Example `asset-manifest.json` contents:

```
{
  "main.css": "static/css/main.2c2ee846.css",
  "main.js": "static/js/main.fb659025.js"
}
```

HIRO Desktop loads `main.js` and all `.css` files found in manifest.

After we've made a production build, we need to bundle the app.  
`hiro-sdk bundle` command creates a `bundle.zip` archive in the project root.

### hiro-sdk publish

Publishes bundled application (`bundle.zip`) to the graph.

You can provide either host/token/parent combination to command or read those values from env files.

Using explicit arguments:

- `-h` = Graph URL
- `-t` = Graph token
- `-p` = Desktop "ui" app ID on your installation

Using implicit arguments: just pass `-e` flag to read arguments from .env files

- `HIRO_GRAPH_URL` = Graph URL
- `HIRO_GRAPH_TOKEN` = Graph token
- `HIRO_DESKTOP_ID` = Desktop "ui" app ID on your installation

```
# Explicit arguments
hiro-sdk publish -h https://acme.graphit.co -t vm8127v89126cn8712616c12c12 -p awv8a57wavmawvawawvaw

# Implicit arguments
hiro-sdk publish -e
```

As result, your application will be either created or updated, depending on `name` field in the `manifest.yaml`.
NOTE, that you can only update applications uploaded by you.

Use `hiro-sdk --help` to get more info
